@@ -1,73 +1,21 @@
-package MarpaX::Languages::C::AST;
-
 use strict;
 use warnings FATAL => 'all';
+
+package MarpaX::Languages::C::AST;
+BEGIN {
+  $MarpaX::Languages::C::AST::AUTHORITY = 'cpan:JDDPAUSE';
+}
+
+# ABSTRACT: Translate a C source to an AST
+
 use Log::Any qw/$log/;
 use Carp qw/croak/;
 use MarpaX::Languages::C::AST::Grammar;
 use MarpaX::Languages::C::AST::Impl qw/DOT_COMPLETION DOT_PREDICTION/;
 use MarpaX::Languages::C::AST::Scope;
-use feature "switch";
 
-=head1 NAME
+our $VERSION = '0.04'; # VERSION
 
-MarpaX::Languages::C::AST - Translate a C source to an AST
-
-=head1 VERSION
-
-Version 0.03
-
-=cut
-
-our $VERSION = '0.03';
-
-
-=head1 SYNOPSIS
-
-This modules translates a C source into an AST tree. The AST consist of blessed objects that map exactly to the C grammar in use. If you want to enable logging, be aware that this module is a Log::Any thingy.
-
-Please note that this module just I<translates> a C source, it does I<not> check for its correctness, i.e. the numerous grammar constraints built on top on the C grammar are not implemented, for example constraint on the number of storage class specifiers, uniqueness of labeled statements within a function, etc.. This is left to a compiler, which is not the goal here. So, to state things clearly, this module is adressing the I<ambiguities> of the grammar itself, i.e. the dangling else, the typedef/enum/identifier. And produces an AST of the parse tree value.
-
-Example:
-
-#!env perl
-use strict;
-use warnings FATAL => 'all';
-use MarpaX::Languages::C::AST;
-use Log::Log4perl qw/:easy/;
-use Log::Any::Adapter;
-use Log::Any qw/$log/;
-use Data::Dumper;
-#
-# Init log
-#
-our $defaultLog4perlConf = <<DEFAULT_LOG4PERL_CONF;
-log4perl.rootLogger              = WARN, Screen
-log4perl.appender.Screen         = Log::Log4perl::Appender::Screen
-log4perl.appender.Screen.stderr  = 0
-log4perl.appender.Screen.layout  = PatternLayout
-log4perl.appender.Screen.layout.ConversionPattern = %d %-5p %6P %m{chomp}%n
-DEFAULT_LOG4PERL_CONF
-Log::Log4perl::init(\$defaultLog4perlConf);
-Log::Any::Adapter->set('Log4perl');
-#
-# Parse C
-#
-my $cSourceCode = <<C_SOURCE_CODE;
-typedef struct s1_ {int i1;} x1, y1;
-struct x1 {x1 i2;};
-x1 x;
-C_SOURCE_CODE
-my $cAstObject = MarpaX::Languages::C::AST->new();
-print Dumper($cAstObject->parse(\$cSourceCode));
-
-=head1 SUBROUTINES/METHODS
-
-=head2 new($class, $grammarName)
-
-Instanciate a new object. Takes as parameter an optional base name of a grammar. Default is 'ISO-ANSI-C-2011'.
-
-=cut
 
 sub new {
   my ($class, $grammarName) = @_;
@@ -95,11 +43,6 @@ sub new {
   return $self;
 }
 
-=head2 parse($self, $referenceToSourceCodep, $optionalArrayOfValuesb)
-
-Do the parsing and return the blessed value. Takes as first parameter the reference to a C source code. Takes as optional second parameter a flag saying if the return value should be an array of all values or not. If this flag is false, the module will croak if there more than one parsee tree value.
-
-=cut
 
 sub parse {
   my ($self, $referenceToSourceCodep, $optionalArrayOfValuesb) = @_;
@@ -111,7 +54,6 @@ sub parse {
     $self->_doLexeme();
   } while (($pos = $self->{_impl}->resume()) < $max);
 
-  $optionalArrayOfValuesb ||= 0;
   return($self->_value($optionalArrayOfValuesb));
 }
 
@@ -179,6 +121,8 @@ sub _show_last_expression {
 sub _value {
   my ($self, $arrayOfValuesb) = @_;
 
+  $arrayOfValuesb ||= 0;
+
   my @rc = ();
   my $nvalue = 0;
   my $valuep = $self->{_impl}->value() || croak $self->_show_last_expression();
@@ -323,9 +267,11 @@ sub _doLexeme {
       my $newlexeme;
       if ($self->_expectTypedefName($context) && $self->_canEnterTypedefName($context) && $self->{_scope}->parseIsTypedef($context, $lexeme_value)) {
 	  $newlexeme = 'TYPEDEF_NAME';
-      } elsif ($self->_expectEnum($context) && $self->_canEnterEnumerationConstant($context) && $self->{_scope}->parseIsEnum($context, $lexeme_value)) {
+      }
+      elsif ($self->_expectEnum($context) && $self->_canEnterEnumerationConstant($context) && $self->{_scope}->parseIsEnum($context, $lexeme_value)) {
 	  $newlexeme = 'ENUMERATION_CONSTANT';
-      } else {
+      }
+      else {
 	  $newlexeme = 'IDENTIFIER';
 	  $self->{_identifier} = $lexeme_value;
       }
@@ -349,41 +295,31 @@ sub _doLexeme {
   # -----------------------------------------------------------
   else {
       my $context = $lexeme;
-      given ($lexeme) {
-	  when ('LPAREN_PARAMETER') {
-	      $self->_nbParameterTypeList($context, 1);
-	      $self->{_scope}->parseEnterScope($context);
-	  }
-	  when ('RPAREN_PARAMETER') {
-	      $self->_nbParameterTypeList($context, -1);
-	      $self->{_scope}->parseExitScope($context);
-	  }
-	  when ('LPAREN_IDENTIFIERLIST') {
-	      $self->{_scope}->parseEnterScope($context);
-	  }
-	  when ('RPAREN_IDENTIFIERLIST') {
-	      $self->{_scope}->parseExitScope($context);
-	  }
-	  when ('LCURLY_COMPOUNDSTATEMENT') {
-	      if ($self->_canReenterScope()) {
-		  $self->{_scope}->parseReenterScope($context);
-	      } else {
-		  $self->{_scope}->parseEnterScope($context);
-	      }
-	  }
-	  when ('RCURLY_COMPOUNDSTATEMENT') {
-	      $self->{_scope}->parseExitScope($context);
-	  }
-	  when ($lexeme eq 'LCURLY_STRUCTDECLARATIONLIST') {
-	      $self->_nbStructDeclarationList($context, 1);
-	  }
-	  when ('RCURLY_STRUCTDECLARATIONLIST') {
-	      $self->_nbStructDeclarationList($context, -1);
-	  }
-	  when ('TYPEDEF') {
-	      $self->_nbTypedef($context, 1);
-	  }
-      }
+      # ----------------
+      # Scope management
+      # ----------------
+      #
+      # Enter/Reenter
+      #
+      if    ($lexeme eq 'LPAREN_PARAMETER')             {  $self->{_scope}->parseEnterScope($context); }
+      elsif ($lexeme eq 'LPAREN_IDENTIFIERLIST')        {  $self->{_scope}->parseEnterScope($context); }
+      elsif ($lexeme eq 'LCURLY_COMPOUNDSTATEMENT')     {$self->_canReenterScope() ?
+                                                           $self->{_scope}->parseReenterScope($context) :
+                                                           $self->{_scope}->parseEnterScope($context); }
+      #
+      # Exit
+      #
+      if    ($lexeme eq 'RPAREN_PARAMETER')             { $self->{_scope}->parseExitScope($context); }
+      elsif ($lexeme eq 'RPAREN_IDENTIFIERLIST')        { $self->{_scope}->parseExitScope($context); }
+      elsif ($lexeme eq 'RCURLY_COMPOUNDSTATEMENT')     { $self->{_scope}->parseExitScope($context); }
+      # ------------------
+      # Context management
+      # ------------------
+      if    ($lexeme eq 'LPAREN_PARAMETER')             { $self->_nbParameterTypeList($context, 1);      }
+      elsif ($lexeme eq 'RPAREN_PARAMETER')             { $self->_nbParameterTypeList($context, -1);     }
+      elsif ($lexeme eq 'LCURLY_STRUCTDECLARATIONLIST') { $self->_nbStructDeclarationList($context, 1);  }
+      elsif ($lexeme eq 'RCURLY_STRUCTDECLARATIONLIST') { $self->_nbStructDeclarationList($context, -1); }
+      elsif ($lexeme eq 'TYPEDEF')                      { $self->_nbTypedef($context, 1);                }
   }
 }
 
@@ -445,97 +381,77 @@ sub _canReenterScope {
           $self->{_impl}->findInProgressShort(-2, 2, 'functionDefinition', [ 'declarationSpecifiers', 'declarator', 'compoundStatement' ]));
 }
 
-=head1 SEE ALSO
+1;
 
-L<Log::Any>, L<MarpaX::Languages::C::AST::Grammar>, L<MarpaX::Languages::C::AST::Impl>, L<MarpaX::Languages::C::AST::Scope>
+__END__
+
+=pod
+
+=head1 NAME
+
+MarpaX::Languages::C::AST - Translate a C source to an AST
+
+=head1 VERSION
+
+version 0.04
+
+=head1 SYNOPSIS
+
+    use strict;
+    use warnings FATAL => 'all';
+    use MarpaX::Languages::C::AST;
+    use Log::Log4perl qw/:easy/;
+    use Log::Any::Adapter;
+    use Log::Any qw/$log/;
+    use Data::Dumper;
+    #
+    # Init log
+    #
+    our $defaultLog4perlConf = '
+    log4perl.rootLogger              = WARN, Screen
+    log4perl.appender.Screen         = Log::Log4perl::Appender::Screen
+    log4perl.appender.Screen.stderr  = 0
+    log4perl.appender.Screen.layout  = PatternLayout
+    log4perl.appender.Screen.layout.ConversionPattern = %d %-5p %6P %m{chomp}%n
+    ';
+    Log::Log4perl::init(\$defaultLog4perlConf);
+    Log::Any::Adapter->set('Log4perl');
+    #
+    # Parse C
+    #
+    my $cSourceCode = '
+    typedef struct s1_ {int i1;} x1, y1;
+    struct x1 {x1 i2;};
+    x1 x;
+    ';
+    my $cAstObject = MarpaX::Languages::C::AST->new();
+    print Dumper($cAstObject->parse(\$cSourceCode));
+
+=head1 DESCRIPTION
+
+This modules translates a C source into an AST tree. The AST consist of blessed objects that map exactly to the C grammar in use. If you want to enable logging, be aware that this module is a Log::Any thingy.
+
+Please note that this module just I<translates> a C source, it does I<not> check for its correctness, i.e. the numerous grammar constraints built on top on the C grammar are not implemented, for example constraint on the number of storage class specifiers, uniqueness of labeled statements within a function, etc.. This is left to a compiler, which is not the goal here. So, to state things clearly, this module is adressing the I<ambiguities> of the grammar itself, i.e. the dangling else, the typedef/enum/identifier. And produces an AST of the parse tree value.
+
+=head1 SUBROUTINES/METHODS
+
+=head2 new($class, $grammarName)
+
+Instanciate a new object. Takes as parameter an optional base name of a grammar. Default is 'ISO-ANSI-C-2011'.
+
+=head2 parse($self, $referenceToSourceCodep, $optionalArrayOfValuesb)
+
+Do the parsing and return the blessed value. Takes as first parameter the reference to a C source code. Takes as optional second parameter a flag saying if the return value should be an array of all values or not. If this flag is false, the module will croak if there more than one parse tree value.
 
 =head1 AUTHOR
 
-Jean-Damien Durand, C<< <jeandamiendurand at free.fr> >>
+Jean-Damien Durand <jeandamiendurand@free.fr>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to C<bug-marpax-language-c-ast at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MarpaX-Languages-C-AST>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc MarpaX::Languages::C::AST
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker (report bugs here)
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=MarpaX-Languages-C-AST>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/MarpaX-Languages-C-AST>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/MarpaX-Languages-C-AST>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/MarpaX-Languages-C-AST/>
-
-=back
-
-
-=head1 ACKNOWLEDGEMENTS
-
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2013 Jean-Damien Durand.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+This software is copyright (c) 2013 by Jean-Damien Durand.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1; # End of MarpaX::Languages::C::AST
